==> flulm_auth-0.0.1.tar.gz: android/src/main/java/com/awesome/flulm_auth/lmapi/FluwxLmEntryActivity.kt <==
/*
 * Copyright (C) 2018 The OpenFlutter Organization
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.awesome.flulm_auth.lmapi

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import com.awesome.flulm_auth.handler.FluLmRequestHandler
import com.awesome.flulm_auth.handler.FluLmResponseHandler
import com.awesome.flulm_auth.handler.LmAPiHandler
import com.awesomeglobal.paysdk.auth.ILMAPIEventHandler
import com.awesomeglobal.paysdk.auth.model.BaseReq
import com.awesomeglobal.paysdk.auth.model.BaseResp
import io.flutter.Log


open class FluLmEntryActivity : Activity(), ILMAPIEventHandler {


    // IWXAPI 是第三方app和微信通信的openapi接口

    public override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        Log.d("azhansy", "FluLmEntryActivity======create======")
        try {
            LmAPiHandler.lmAuth?.handleIntent(intent, this)
        } catch (e: Exception) {
            e.printStackTrace()
            finish()
        }

    }

    override fun onNewIntent(intent: Intent) {
        super.onNewIntent(intent)
        Log.d("azhansy", "FluLmEntryActivity======onNewIntent======")
        setIntent(intent)
        try {
            LmAPiHandler.lmAuth?.handleIntent(intent, this)
        } catch (e: Exception) {
            e.printStackTrace()
            finish()
        }
    }


    override fun onReq(baseReq: BaseReq) {
        val activity = FluLmRequestHandler.getRegistrar()?.activity()
        if (baseReq.type == 1 && activity is Activity) {
            startActivity(Intent(this, activity::class.java))
            finish()
        }
    }

    // 第三方应用发送到微信的请求处理后的响应结果，会回调到该方法
    override fun onResp(resp: BaseResp) {
        FluLmResponseHandler.handleResponse(resp)
        finish()
    }


}

==> flulm_auth-0.1.1.tar.gz: android/src/main/java/com/awesome/flulm_auth/lmapi/FluwxLmEntryActivity.kt <==
/*
 * Copyright (C) 2018 The OpenFlutter Organization
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.awesome.flulm_auth.lmapi

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import com.awesome.flulm_auth.handler.FluLmRequestHandler
import com.awesome.flulm_auth.handler.FluLmResponseHandler
import com.awesome.flulm_auth.handler.LmAPiHandler
import com.awesomeglobal.paysdk.modelbase.BaseReq
import com.awesomeglobal.paysdk.modelbase.BaseResp
import com.awesomeglobal.paysdk.openapi.ILMAPIEventHandler
import io.flutter.Log


open class FluLmEntryActivity : Activity(), ILMAPIEventHandler {


    // IWXAPI 是第三方app和微信通信的openapi接口

    public override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        Log.d("azhansy", "FluLmEntryActivity======create======")
        try {
            LmAPiHandler.lmAuth?.handleIntent(intent, this)
        } catch (e: Exception) {
            e.printStackTrace()
            finish()
        }

    }

    override fun onNewIntent(intent: Intent) {
        super.onNewIntent(intent)
        Log.d("azhansy", "FluLmEntryActivity======onNewIntent======")
        setIntent(intent)
        try {
            LmAPiHandler.lmAuth?.handleIntent(intent, this)
        } catch (e: Exception) {
            e.printStackTrace()
            finish()
        }
    }


    override fun onReq(baseReq: BaseReq) {
        val activity = FluLmRequestHandler.getRegistrar()?.activity()
        if (baseReq.type == 1 && activity is Activity) {
            startActivity(Intent(this, activity::class.java))
            finish()
        }
    }

    // 第三方应用发送到微信的请求处理后的响应结果，会回调到该方法
    override fun onResp(resp: BaseResp) {
        FluLmResponseHandler.handleResponse(resp)
        finish()
    }


}
